==> odoo_14.0.0+dfsg.3.orig.tar.xz: odoo-14.0.0+dfsg.3/addons/crm/README.md <==
Odoo CRM
--------

Boost sales productivity, improve win rates, grow revenue with the Odoo
<a href="https://www.odoo.com/page/crm">Open Source CRM</a>.

Manage your sales funnel with no effort. Attract leads, follow-up on phone
calls and meetings. Analyse the quality of your leads to make informed
decisions and save time by integrating emails directly into the application.

Your Sales Funnel, The Way You Like It
--------------------------------------

Track your opportunities pipeline with the revolutionary kanban view. Work
inside your sales funnel and get instant visual information about next actions,
new messages, top opportunities and expected revenues.

Lead Management Made Easy
-------------------------

Create leads automatically from incoming emails. Analyse leads efficiency and
compare performance by campaigns, channels or Sales Team.

Find duplicates, merge leads and assign them to the right salesperson in one
operation. Spend less time on administration and more time on qualifying leads.

Organize Your Opportunities
---------------------------

Get your opportunities organized to stay focused on the best deals. Manage all
your customer interactions from the opportunity like emails, phone calls,
internal notes, meetings and quotations.

Follow opportunities that interest you to get notified upon specific events:
deal won or lost, stage changed, new customer demand, etc.

Email Integration and Automation
--------------------------------

Work with the email applications you already use every day. Whether your
company uses Microsoft Outlook or Gmail, no one needs to change the way they
work, so everyone stays productive.

Route, sort and filter incoming emails automatically. Odoo CRM handles incoming
emails and route them to the right opportunities or Sales Team. New leads are
created on the fly and interested salespersons are notified automatically.

Collaborative Agenda
--------------------

Schedule your meetings and phone calls using the integrated calendar. You can
see your agenda and your colleagues' in one view. As a manager, it's easy to
see what your team is busy with.

Lead Automation and Marketing Campaigns
---------------------------------------

Drive performance by automating tasks with Odoo <a href="https://www.odoo.com/page/crm">CRM</a>.

Use our marketing campaigns to automate lead acquisition, follow ups and
promotions. Define automated actions (e.g. ask a salesperson to call, send an
email, ...) based on triggers (no activity since 20 days, answered a
promotional email, etc.)

Optimize campaigns from lead to close, on every channel. Make smarter decisions
about where to invest and show the impact of your marketing activities on your
company's bottom line.

Customize Your Sales Cycle
--------------------------

Customize your sales cycle by configuring sales stages that perfectly fit your
sales approach. Control statistics to get accurate forecasts to improve your
sales performance at every stage of your customer relationship.

Drive Engagement with Gamification
----------------------------------

### Leverage your team's natural desire for competition

Reinforce good habits and improve win rates with real-time recognition and
rewards inspired by [game mechanics](http://en.wikipedia.org/wiki/Gamification).
Align Sales Teams around clear business objectives with challenges, personal
objectives and team leader boards.

### Leaderboards

Promote leaders and competition amongst Sales Team with performance ratios.

### Personal Objectives

Assign clear goals to users to align them with the company objectives.

### Team Targets

Compare revenues with forecasts and budgets in real time.

==> odoo_16.0.0+dfsg.2.orig.tar.xz: odoo-16.0.0+dfsg.2/addons/crm/README.md <==
Odoo CRM
--------

Boost sales productivity, improve win rates, grow revenue with the Odoo
<a href="https://www.odoo.com/app/crm">Open Source CRM</a>.

Manage your sales funnel with no effort. Attract leads, follow-up on phone
calls and meetings. Analyse the quality of your leads to make informed
decisions and save time by integrating emails directly into the application.

Your Sales Funnel, The Way You Like It
--------------------------------------

Track your opportunities pipeline with the revolutionary kanban view. Work
inside your sales funnel and get instant visual information about next actions,
new messages, top opportunities and expected revenues.

Lead Management Made Easy
-------------------------

Create leads automatically from incoming emails. Analyse leads efficiency and
compare performance by campaigns, channels or Sales Team.

Find duplicates, merge leads and assign them to the right salesperson in one
operation. Spend less time on administration and more time on qualifying leads.

Organize Your Opportunities
---------------------------

Get your opportunities organized to stay focused on the best deals. Manage all
your customer interactions from the opportunity like emails, phone calls,
internal notes, meetings and quotations.

Follow opportunities that interest you to get notified upon specific events:
deal won or lost, stage changed, new customer demand, etc.

Email Integration and Automation
--------------------------------

Work with the email applications you already use every day. Whether your
company uses Microsoft Outlook or Gmail, no one needs to change the way they
work, so everyone stays productive.

Route, sort and filter incoming emails automatically. Odoo CRM handles incoming
emails and route them to the right opportunities or Sales Team. New leads are
created on the fly and interested salespersons are notified automatically.

Collaborative Agenda
--------------------

Schedule your meetings and phone calls using the integrated calendar. You can
see your agenda and your colleagues' in one view. As a manager, it's easy to
see what your team is busy with.

Lead Automation and Marketing Campaigns
---------------------------------------

Drive performance by automating tasks with Odoo <a href="https://www.odoo.com/app/crm">CRM</a>.

Use our marketing campaigns to automate lead acquisition, follow ups and
promotions. Define automated actions (e.g. ask a salesperson to call, send an
email, ...) based on triggers (no activity since 20 days, answered a
promotional email, etc.)

Optimize campaigns from lead to close, on every channel. Make smarter decisions
about where to invest and show the impact of your marketing activities on your
company's bottom line.

Customize Your Sales Cycle
--------------------------

Customize your sales cycle by configuring sales stages that perfectly fit your
sales approach. Control statistics to get accurate forecasts to improve your
sales performance at every stage of your customer relationship.

Drive Engagement with Gamification
----------------------------------

### Leverage your team's natural desire for competition

Reinforce good habits and improve win rates with real-time recognition and
rewards inspired by [game mechanics](http://en.wikipedia.org/wiki/Gamification).
Align Sales Teams around clear business objectives with challenges, personal
objectives and team leader boards.

### Leaderboards

Promote leaders and competition amongst Sales Team with performance ratios.

### Personal Objectives

Assign clear goals to users to align them with the company objectives.

### Team Targets

Compare revenues with forecasts and budgets in real time.
